RouteDescription class

Constructors

RouteDescription({required String method, required String uri, required List<String> middleware, String? name})
const
RouteDescription.fromJson(dynamic value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
method String
final
middleware List<String>
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited