help property
Implementation
@override
String get help => '''
Keys while running:
r hot reload re-compile changed libraries in place
R restart start the process again from scratch
l list routes print the routing table
c clear clear the screen
q quit stop the server and exit
Options:
--host <host> host to bind (overrides APP_HOST)
--port <port> port to bind (overrides APP_PORT)
--no-reload restart the process on change instead of hot reloading
--no-watch do not watch for file changes at all''';