StubCommand class abstract

Shared, safe file creation workflow for simple make: commands.

Inheritance
Implementers

Constructors

StubCommand()

Properties

description String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
help String
no setteroverride
label String
no setter
name String
no setterinherited
requiresProject bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usage String
no setteroverride
workingDirectory Directory
getter/setter pairinherited

Methods

execute(List<String> arguments) Future<int>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pathFor(String name) String
printUsage() → void
inherited
render(String name, List<String> arguments) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited