Console class abstract final

Consistent terminal output with automatic colour detection.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

blue(String value) String
bold(String value) String
clear() → void
cyan(String value) String
dim(String value) String
error(String value) → void
green(String value) String
info(String value) → void
line([String value = '']) → void
magenta(String value) String
red(String value) String
success(String value) → void
table(List<String> headers, List<List<String>> rows, {String colorize(int column, String value)?}) → void
warn(String value) → void
yellow(String value) String