HotReloadService class

Applies an incremental VM reload for one changed Dart source.

The VM protocol has no per-file argument. With force disabled it checks modification times and incrementally recompiles only dirty libraries and the dependencies required to make the program consistent.

Constructors

HotReloadService(VmServiceGateway _gateway)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reloadChangedFile(String changedFile) Future<HotReloadResult>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited