ServeDownCommand class
Constructors
Properties
- description → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- help → String
-
no setterinherited
- name → String
-
no setteroverride
- requiresProject → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usage → String
-
no setterinherited
- workingDirectory ↔ Directory
-
getter/setter pairinherited
Methods
-
execute(
List< String> arguments) → Future<int> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printUsage(
) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited